<?php 
// Check Profiler COMPONENT
//
//include the helper file
require_once(dirname(__FILE__).'/../componenthelper.inc.php');

/* respect the name */
$check_profiler_component_name = 'check_profiler';

/* run the initialization function */
check_profiler_component_init();

////////////////////////////////////////////////////////////////////////
// COMPONENT INIT FUNCTIONS
////////////////////////////////////////////////////////////////////////

function check_profiler_component_init(){
	global $check_profiler_component_name;
	
	/* boolean to check for latest version */
	$versionok = check_profiler_component_checkversion();
	
	/* Define a description */
	$desc = 'The purpose of the Check Profiler is to allow you to look at how long checks take to execute on your Nagios XI host.<br />The Check Profiler is accessed via the Tools menu under "Tools by Box293".<br /><b>NOTE:</b> The Check Profiler is ONLY accessible by Admins!<br />';
	
	if(!$versionok) {
		$desc .= '<br/><b>Error: This component requires Nagios XI 2014R1.2 or later ... it will NOT appear under the Tools menu!</b><br/>';
		} /* End if(!$versionok) { */
		
	/* all components require a few arguments to be initialized correctly. */
	$args = array(
		COMPONENT_NAME => $check_profiler_component_name,
		COMPONENT_VERSION => '2016-04-01', 
		COMPONENT_DATE => '2016-04-01',
		COMPONENT_AUTHOR => "Troy Lea aka Box293",
		COMPONENT_DESCRIPTION => $desc,
		COMPONENT_TITLE => "Check Profiler",
		);
	
	/* Register this component with XI */
	register_component($check_profiler_component_name,$args);
	
	/* Register the addmenu function */
	if($versionok) {
		register_callback(CALLBACK_MENUS_INITIALIZED,'check_profiler_component_addmenu');
		} /* End if($versionok) { */
	} /* End function check_profiler_component_init(){ */


///////////////////////////////////////////////////////////////////////////////////////////
// MISC FUNCTIONS
///////////////////////////////////////////////////////////////////////////////////////////

function check_profiler_component_checkversion() {

	if(!function_exists('get_product_release')) {
		return false;
		} /* End if(!function_exists('get_product_release')) */
	/* Requires 2014R1.2 */
	if(get_product_release()<405) {
		return false;
		} /* End if(get_product_release()<405) { */
	return true;
	} /* End function check_profiler_component_checkversion() { */


function check_profiler_component_addmenu($arg=null) {
	/* Only show the menu if the user is an admin */
	if(is_admin() == true) {
		global $check_profiler_component_name;
		/* Retrieve the URL for this component */
		$urlbase=get_component_url_base($check_profiler_component_name);

		/* Check to see if the "Tools by Box293 menu exists */
		$menu_check = find_menu_item(MENU_TOOLS,"menu-tools-section-toolsbybox293","id");
		
		/* If the "Tools by Box293 menu does NOT exist add it */
		if ($menu_check == false) {
			/* Tools by Box293 menu */ 
			add_menu_item(MENU_TOOLS,array(
				"type" => "menusection",
				"title" => gettext("Tools by Box293"),
				"id" => "menu-tools-section-toolsbybox293",
				"order" => 10000,
				"opts" => array(
					"id" => "toolsbybox293",
					"expanded" => true,
					)
				));
			} /* End if ($menu_check == false) { */
		
		/* Add this to the Tools by Box293 menu */
		add_menu_item(MENU_TOOLS,array(
			"type" => "link",
			"title" => "Check Profiler",
			"id" => "menu-tools-section-check-profiler",
			"order" => 10300,
			"opts" => array(
				/* This is the page the menu will actually point to */
				/* all of my actual component workings will happen on this script */
				"href" => $urlbase."/check_profiler.php",      
				)
			));
		
		/* If the "Tools by Box293 menu does NOT exist End it */
		if ($menu_check == false) {
			add_menu_item(MENU_TOOLS,array(
				"type" => "menusectionend",
				"id" => "menu-tools-sectionend-toolsbybox293",
				"order" => 10999,
				"title" => "",
				"opts" => ""
				));
			} /* End if ($menu_check == false) { */
		} // End if(is_admin() == true) {	
	} /* End function check_profiler_component_addmenu($arg=null) { */


?>
